## $Id: interfaces.py 7931 2012-03-21 07:09:23Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
from zope.interface import Attribute
from zope import schema
from waeup.kofa.interfaces import IKofaObject, SimpleKofaVocabulary
from waeup.kofa.interfaces import MessageFactory as _

payment_states = SimpleKofaVocabulary(
    (_('Not yet paid'),'unpaid'),
    (_('Paid'),'paid'),
    (_('Failed'),'failed'),
    )

payment_categories = SimpleKofaVocabulary(
    (_('School Fee'),'schoolfee'),
    (_('Clearance'),'clearance'),
    (_('Bed Allocation'),'bed_allocation'),
    (_('Hostel Maintenance'),'hostel_maintenance'),
    (_('Transfer'),'transfer'),
    (_('Gown'),'gown'),
    (_('Acceptance Fee'), 'acceptance'),
    )

class IPaymentsContainer(IKofaObject):
    """A container for all kind of payment objects.

    """

class IPayment(IKofaObject):
    """A base representation of payments.

    """
    p_id = Attribute('Payment identifier.')

    p_category = schema.Choice(
        title = _(u'Payment Category'),
        default = u'schoolfee',
        vocabulary = payment_categories,
        required = True,
        )

    p_item = schema.TextLine(
        title = _(u'Payment Item'),
        default = None,
        required = False,
        )

    p_state = schema.Choice(
        title = _(u'Payment State'),
        default = u'unpaid',
        vocabulary = payment_states,
        required = True,
        )

    creation_date = schema.Datetime(
        title = _(u'Ticket Creation Date'),
        readonly = False,
        )

    payment_date = schema.Datetime(
        title = _(u'Payment Date'),
        required = False,
        readonly = False,
        )

    amount_auth = schema.Float(
        title = _(u'Amount Authorized'),
        default = 0.0,
        required = True,
        readonly = False,
        )

class ISCPayment(IPayment):
    """A scratch card payment.

    """

    p_code = schema.TextLine(
        title = _(u'Payment Access Code'),
        #default = u'Certificate XYZ',
        required = False,
        readonly = True,
        )

class IOnlinePayment(IPayment):
    """A payment via payment gateways.

    """

    surcharge_1 = schema.Float(
        title = _(u'Portal Fee'),
        default = 0.0,
        required = False,
        readonly = True,
        )

    surcharge_2 = schema.Float(
        title = _(u'Surcharge 2'),
        default = 0.0,
        required = False,
        readonly = True,
        )

    surcharge_3 = schema.Float(
        title = _(u'Surcharge 3'),
        default = 0.0,
        required = False,
        readonly = True,
        )

    #order_id = schema.TextLine(
    #    title = u'Order Id',
    #    default = None,
    #    required = True,
    #    )

    ac = schema.TextLine(
        title = _(u'Activation Code'),
        default = None,
        required = False,
        readonly = False,
        )

    r_amount_approved = schema.Float(
        title = _(u'Response Amount Approved'),
        default = 0.0,
        required = False,
        readonly = False,
        )

    r_desc = schema.TextLine(
        title = _(u'Response Description'),
        default = None,
        required = False,
        readonly = False,
        )

    r_pay_reference = schema.TextLine(
        title = _(u'Response Payment Reference'),
        default = None,
        required = False,
        readonly = False,
        )

    r_code = schema.TextLine(
        title = _(u'Response Code'),
        default = None,
        required = False,
        readonly = False,
        )

    r_card_num = schema.TextLine(
        title = _(u'Response Card Number'),
        default = None,
        required = False,
        readonly = False,
        )
